==> haskell-configurator-ng-0.0.0.1-58-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-configurator-ng.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: configurator-ng
version: 0.0.0.1
id: configurator-ng-0.0.0.1-5zJsdnk0ozxF0CzoJYeE7j
key: configurator-ng-0.0.0.1-5zJsdnk0ozxF0CzoJYeE7j
license: BSD-3-Clause
copyright: Copyright 2011 MailRank, Inc.
           Copyright 2011-2014 Bryan O'\''Sullivan
           Copyright 2015-2016 Leon P Smith
maintainer: Leon P Smith <leon@melding-monads.com>
author: Bryan O'\''Sullivan, Leon P Smith
stability: experimental
homepage: http://github.com/lpsmith/configurator-ng
synopsis: The next generation of configuration management
description:
    A configuration management library for programs and daemons.
    .
    Features include:
    .
    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).
    .
    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.
    .
    * An expressive applicative/monadic high-level parsing interface
    to gracefully scale to more complicated configuration needs,  with
    powerful diagnostic messaging mechanism.
    .
    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.
category: Configuration, Data
abi: dceafbe6f59abfb6cd91552dfd6d0268
exposed: True
exposed-modules:
    Data.Configurator Data.Configurator.Config
    Data.Configurator.Config.Internal Data.Configurator.FromValue
    Data.Configurator.FromValue.Internal Data.Configurator.Parser
    Data.Configurator.Parser.Internal Data.Configurator.Types
hidden-modules: Data.Configurator.Config.Implementation
                Data.Configurator.Parser.Implementation
                Data.Configurator.FromValue.Implementation Data.Configurator.Syntax
                Data.Configurator.Types.Internal
import-dirs: /usr/lib/ghc-8.6.4/site-local/configurator-ng-0.0.0.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/configurator-ng-0.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/configurator-ng-0.0.0.1
hs-libraries: HSconfigurator-ng-0.0.0.1-5zJsdnk0ozxF0CzoJYeE7j
depends:
    attoparsec-0.13.2.2-4iFLH0ONEYhG16eDwwtqQO base-4.12.0.0
    bytestring-0.10.8.2 critbit-0.2.0.0-3jjDYCIOeMs2Km5BDsUdWo
    data-ordlist-0.4.7.0-JijOptHq8X5AysaK6Liyhk directory-1.3.3.0
    dlist-0.8.0.6-CQRMCGRgL5B3ZxhntX4iOr
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR text-1.2.3.1
    unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
haddock-interfaces: /usr/share/doc/haskell-configurator-ng/html/configurator-ng.haddock
haddock-html: /usr/share/doc/haskell-configurator-ng/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configurator-ng-0.0.0.1-60-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-configurator-ng.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: configurator-ng
version: 0.0.0.1
id: configurator-ng-0.0.0.1-LmHwF9EGLohF0XwVIkP7Bn
key: configurator-ng-0.0.0.1-LmHwF9EGLohF0XwVIkP7Bn
license: BSD-3-Clause
copyright: Copyright 2011 MailRank, Inc.
           Copyright 2011-2014 Bryan O'\''Sullivan
           Copyright 2015-2016 Leon P Smith
maintainer: Leon P Smith <leon@melding-monads.com>
author: Bryan O'\''Sullivan, Leon P Smith
stability: experimental
homepage: http://github.com/lpsmith/configurator-ng
synopsis: The next generation of configuration management
description:
    A configuration management library for programs and daemons.
    .
    Features include:
    .
    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).
    .
    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.
    .
    * An expressive applicative/monadic high-level parsing interface
    to gracefully scale to more complicated configuration needs,  with
    powerful diagnostic messaging mechanism.
    .
    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.
category: Configuration, Data
abi: 27a60b64c21e9a02853ad722aef0e3d5
exposed: True
exposed-modules:
    Data.Configurator Data.Configurator.Config
    Data.Configurator.Config.Internal Data.Configurator.FromValue
    Data.Configurator.FromValue.Internal Data.Configurator.Parser
    Data.Configurator.Parser.Internal Data.Configurator.Types
hidden-modules: Data.Configurator.Config.Implementation
                Data.Configurator.Parser.Implementation
                Data.Configurator.FromValue.Implementation Data.Configurator.Syntax
                Data.Configurator.Types.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/configurator-ng-0.0.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/configurator-ng-0.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/configurator-ng-0.0.0.1
hs-libraries: HSconfigurator-ng-0.0.0.1-LmHwF9EGLohF0XwVIkP7Bn
depends:
    attoparsec-0.13.2.2-3nUJVHBWBICGFmP4JcM3ay base-4.12.0.0
    bytestring-0.10.8.2 critbit-0.2.0.0-3jjDYCIOeMs2Km5BDsUdWo
    data-ordlist-0.4.7.0-JijOptHq8X5AysaK6Liyhk directory-1.3.3.0
    dlist-0.8.0.6-CQRMCGRgL5B3ZxhntX4iOr
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
haddock-interfaces: /usr/share/doc/haskell-configurator-ng/html/configurator-ng.haddock
haddock-html: /usr/share/doc/haskell-configurator-ng/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
